<?php

namespace Drupal\rcr\Commands;

use Drupal\Core\State\StateInterface;
use Drush\Commands\DrushCommands;

/**
 * A Drush commandfile.
 *
 * In addition to this file, you need a drush.services.yml
 * in root of your module, and a composer.json file that provides the name
 * of the services file to use.
 */
class Drush9Commands extends DrushCommands {

  /**
   * The state store.
   *
   * @var \Drupal\Core\State\StateInterface
   */
  protected $state;

  /**
   * Drush command constructor.
   *
   * @param \Drupal\Core\State\StateInterface $state
   *   The state store.
   */
  public function __construct(StateInterface $state) {
    $this->state = $state;
  }

  /**
   * Get current rates.
   *
   * @command rcr:getrates
   * @aliases rcr-getrates
   * @usage rcr:getrates
   */
  public function getrates() {
    $nowStr = date('d.m.Y', time());
    $dataxml = file_get_contents('https://www.cbr.ru/scripts/XML_daily.asp?date_req=' . $nowStr);
    if ($dataxml !== FALSE) {
      $xml = new \SimpleXMLElement($dataxml);
      if (!empty($xml->Valute)) {
        foreach ($xml->Valute as $v) {
          if ($v->CharCode == 'USD') {
            $replace_comma = str_replace(',', '.', $v->Value);
            $this->state->set('rcr.usd', round($replace_comma, 2));
            $this->output()->writeln('USD rate was saved');
          }
          if ($v->CharCode == 'EUR') {
            $replace_comma = str_replace(',', '.', $v->Value);
            $this->state->set('rcr.eur', round($replace_comma, 2));
            $this->output()->writeln('EUR rate was saved');
          }
        }
      }
    }
    else {
      $this->output()->writeln('Can not get current rates from www.cbr.ru');
    }
  }

}
